package com.ruoyi.invest.service;

import java.util.List;
import com.ruoyi.invest.domain.TProjectContract;

/**
 * 合同管理Service接口
 * 
 * @author ruoyi
 * @date 2024-02-23
 */
public interface ITProjectContractService 
{
    /**
     * 查询合同管理
     * 
     * @param id 合同管理主键
     * @return 合同管理
     */
    public TProjectContract selectTProjectContractById(String id);

    /**
     * 查询合同管理列表
     * 
     * @param tProjectContract 合同管理
     * @return 合同管理集合
     */
    public List<TProjectContract> selectTProjectContractList(TProjectContract tProjectContract);

    /**
     * 新增合同管理
     * 
     * @param tProjectContract 合同管理
     * @return 结果
     */
    public int insertTProjectContract(TProjectContract tProjectContract);

    /**
     * 修改合同管理
     * 
     * @param tProjectContract 合同管理
     * @return 结果
     */
    public int updateTProjectContract(TProjectContract tProjectContract);

    /**
     * 批量删除合同管理
     * 
     * @param ids 需要删除的合同管理主键集合
     * @return 结果
     */
    public int deleteTProjectContractByIds(String[] ids);

    /**
     * 删除合同管理信息
     * 
     * @param id 合同管理主键
     * @return 结果
     */
    public int deleteTProjectContractById(String id);
}
